# Tensorflow 2 for Raspberry Pi

## This is a mirror copy of Tensorflow 2.2.0 for the latest Raspberry Pi OS and Python 3

## https://github.com/lhelontra/tensorflow-on-arm

### Tested to work with Python 3.9 and latest vanilla Raspberry Pi OS installed on Raspberry Pi 4
